==> libcamera-docs-0.3.2-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/search/variables_6.js <==
var searchData=
[
  ['gain_0',['gain',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a3a7638e95fd279297ef220bdd356c03e',1,'libcamera::ipa::ipu3::IPAActiveState::gain'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext.html#a45596b968fae1e862bff4a9809bc3274',1,'libcamera::ipa::ipu3::IPAFrameContext::gain']]],
  ['gainconstants_5f_1',['gainConstants_',['../classlibcamera_1_1ipa_1_1CameraSensorHelper.html#af0e61d5dee7d9da3b8e4eddfbebc42fa',1,'libcamera::ipa::CameraSensorHelper']]],
  ['gains_2',['gains',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a1b4387c5a0ee110ab316bff01749e7ce',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['gaintype_5f_3',['gainType_',['../classlibcamera_1_1ipa_1_1CameraSensorHelper.html#a46962ed6c3f3e9ff91178f5106fdc053',1,'libcamera::ipa::CameraSensorHelper']]],
  ['gamma_4',['Gamma',['../namespacelibcamera_1_1controls.html#ad38572b6737088a467f9923a83f28bae',1,'libcamera::controls']]],
  ['gamma_5',['gamma',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a03893bd512cb7141bf340fe508675695',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['gammacorrection_6',['gammaCorrection',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#aa38b7e2b5160b1a342e4c55ad2df7e5d',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['green_7',['green',['../structlibcamera_1_1DebayerParams.html#a6c77abeefe6253d5fef123659bbad523',1,'libcamera::DebayerParams::green'],['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#af7531392760fc28dfc4dd4f10e3fdd9d',1,'libcamera::ipa::ipu3::algorithms::Accumulator::green'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a21da8c4c3354b701b8fda9b8debd55d7',1,'libcamera::ipa::ipu3::IPAActiveState::green']]],
  ['grid_8',['grid',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration.html#a4fdd207bb04f08d9e27fce2927ad1a8a',1,'libcamera::ipa::ipu3::IPASessionConfiguration']]]
];

==> libcamera-docs-0.4.0-1-aarch64.pkg.tar.xz: usr/share/doc/libcamera/internal-api-html/search/variables_6.js <==
var searchData=
[
  ['gain_0',['gain',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a3a7638e95fd279297ef220bdd356c03e',1,'libcamera::ipa::ipu3::IPAActiveState::gain'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAFrameContext.html#a45596b968fae1e862bff4a9809bc3274',1,'libcamera::ipa::ipu3::IPAFrameContext::gain']]],
  ['gain_5f_1',['gain_',['../classlibcamera_1_1ipa_1_1CameraSensorHelper.html#a926d01357f39927cbf67e5239379d9e6',1,'libcamera::ipa::CameraSensorHelper']]],
  ['gaindelay_2',['gainDelay',['../structlibcamera_1_1CameraSensorProperties_1_1SensorDelays.html#ae737f9055a75cb63e674946112bf6afb',1,'libcamera::CameraSensorProperties::SensorDelays']]],
  ['gains_3',['gains',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a95307069c6b0f45176b433cc128f81c0',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['gamma_4',['Gamma',['../namespacelibcamera_1_1controls.html#ad38572b6737088a467f9923a83f28bae',1,'libcamera::controls']]],
  ['gamma_5',['gamma',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a03893bd512cb7141bf340fe508675695',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['gammacorrection_6',['gammaCorrection',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#aa38b7e2b5160b1a342e4c55ad2df7e5d',1,'libcamera::ipa::ipu3::IPAActiveState']]],
  ['green_7',['green',['../structlibcamera_1_1DebayerParams.html#a6c77abeefe6253d5fef123659bbad523',1,'libcamera::DebayerParams::green'],['../structlibcamera_1_1ipa_1_1ipu3_1_1algorithms_1_1Accumulator.html#af7531392760fc28dfc4dd4f10e3fdd9d',1,'libcamera::ipa::ipu3::algorithms::Accumulator::green'],['../structlibcamera_1_1ipa_1_1ipu3_1_1IPAActiveState.html#a21da8c4c3354b701b8fda9b8debd55d7',1,'libcamera::ipa::ipu3::IPAActiveState::green']]],
  ['grid_8',['grid',['../structlibcamera_1_1ipa_1_1ipu3_1_1IPASessionConfiguration.html#ac56c0f07a5c9a3f66f2e5597de84b602',1,'libcamera::ipa::ipu3::IPASessionConfiguration']]]
];
